Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(16)

Unified Diff: include/gpu/GrXferProcessor.h

Issue 1443743002: Rename some processor functions from GL to GLSL (Closed) Base URL: https://skia.googlesource.com/skia.git@primProcs
Patch Set: nits Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « include/gpu/GrFragmentProcessor.h ('k') | include/gpu/effects/GrConstColorProcessor.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/gpu/GrXferProcessor.h
diff --git a/include/gpu/GrXferProcessor.h b/include/gpu/GrXferProcessor.h
index 21b89c53ad8bb49b38f1cc8591d78842f81f144e..4accbc84fa0140746ef220d9e057f8c07434d76c 100644
--- a/include/gpu/GrXferProcessor.h
+++ b/include/gpu/GrXferProcessor.h
@@ -92,15 +92,15 @@ public:
};
/**
* Sets a unique key on the GrProcessorKeyBuilder calls onGetGLProcessorKey(...) to get the
* specific subclass's key.
*/
- void getGLProcessorKey(const GrGLSLCaps& caps, GrProcessorKeyBuilder* b) const;
+ void getGLSLProcessorKey(const GrGLSLCaps& caps, GrProcessorKeyBuilder* b) const;
/** Returns a new instance of the appropriate *GL* implementation class
for the given GrXferProcessor; caller is responsible for deleting
the object. */
- virtual GrGLSLXferProcessor* createGLInstance() const = 0;
+ virtual GrGLSLXferProcessor* createGLSLInstance() const = 0;
/**
* Optimizations for blending / coverage that an OptDrawState should apply to itself.
@@ -214,7 +214,8 @@ public:
from getFactory()).
A return value of true from isEqual() should not be used to test whether the processor would
- generate the same shader code. To test for identical code generation use getGLProcessorKey*/
+ generate the same shader code. To test for identical code generation use getGLSLProcessorKey
+ */
bool isEqual(const GrXferProcessor& that) const {
if (this->classID() != that.classID()) {
@@ -255,8 +256,8 @@ private:
* Sets a unique key on the GrProcessorKeyBuilder that is directly associated with this xfer
* processor's GL backend implementation.
*/
- virtual void onGetGLProcessorKey(const GrGLSLCaps& caps,
- GrProcessorKeyBuilder* b) const = 0;
+ virtual void onGetGLSLProcessorKey(const GrGLSLCaps& caps,
+ GrProcessorKeyBuilder* b) const = 0;
/**
* Determines the type of barrier (if any) required by the subclass. Note that the possibility
« no previous file with comments | « include/gpu/GrFragmentProcessor.h ('k') | include/gpu/effects/GrConstColorProcessor.h » ('j') | no next file with comments »
@@ -92,15 +92,15 @@ public:
};
/**
- * Sets a unique key on the GrProcessorKeyBuilder calls onGetGLProcessorKey(...) to get the
+ * Sets a unique key on the GrProcessorKeyBuilder calls onGetGLSLProcessorKey(...) to get the
* specific subclass's key.
*/

Powered by Google App Engine
This is Rietveld 408576698